Package 'fourSynergy'

Title: Ensemble algorithm for 4C-seq data
Description: fourSynergy is an ensemble algorithm leveraging synergies among the existing 4C-seq algorithms r3C-seq, peakC, r.4cker and fourSig. It uses a weighted voting approach to perform improved interaction calling. fourSynergy supports also differential interaction calling.
Authors: Sophie Wind [aut, cre] (ORCID: <https://orcid.org/0009-0002-1174-8201>), Carolin Walter [aut, fnd] (ORCID: <https://orcid.org/0000-0002-5155-7728>)
Maintainer: Sophie Wind <[email protected]>
License: LGPL-3
Version: 1.1.0
Built: 2026-04-30 17:39:24 UTC
Source: https://github.com/bioc/fourSynergy

Help Index


fourSynergy: Ensemble based interaction calling in 4C-seq data

Description

fourSynergy is an ensemble algorithm leveraging synergies among the existing 4C-seq algorithms r3C-seq, peakC, r.4cker and fourSig. It uses a weighted voting approach to perform improved interaction calling. fourSynergy supports also differential interaction calling.

Author(s)

Maintainer: Sophie Wind [email protected] (ORCID)

Authors:

See Also

Useful links:


checkConfig

Description

checkConfig

Usage

checkConfig(config)

Arguments

config

config file with path.

Value

TRUE if config is valid.

Examples

config <- system.file("extdata", "Datasets", "Demo", "info.yaml",
    package = "fourSynergy")
checkConfig(config)

consensusIa

Description

This function performs an optimized weighted voting of 4C-seq tools.

Usage

consensusIa(ia, model = "F1")

Arguments

ia

fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and other relevant information.

model

Selected optimization model. Either 'F1' or 'AUPRC'.

Value

fourSynergy object with interactions from all base tools and weighted voting results.

Examples

config <- system.file("extdata", "Datasets", "Demo", "info.yaml",
    package = "fourSynergy"
)
res_path <- system.file("extdata", "results", "Demo",
    package = "fourSynergy"
)
tracks <- system.file("extdata", "results", "Demo", "alignment",
    package = "fourSynergy"
)
sia <- createIa(res_path = res_path, config = config, tracks = tracks)
sia <- consensusIa(ia = sia, model = "AUPRC")

createIa

Description

This function reads the interaction bed files created by the pipeline and transfers this information into an GrangesList.

Usage

createIa(res_path = character(), config = list(), tracks = "")

Arguments

res_path

Path to results created by the pipeline. Typically stored in the ⁠results/[dataset]/nearbait_area.bed⁠.

config

Path of config file.

tracks

Path to alignment files.

Value

fourSynergy object with interactions from all base tools.

Examples

config <- system.file("extdata", "Datasets", "Demo", "info.yaml",
    package = "fourSynergy"
)
res_path <- system.file("extdata", "results", "Demo",
    package = "fourSynergy"
)
tracks <- system.file("extdata", "results", "Demo", "alignment",
    package = "fourSynergy"
)
ia <- createIa(res_path = res_path, config = config, tracks = tracks)

differentialAnalysis

Description

This function performs differential analysis to identify differential interacting regions using DESeq2.

Usage

differentialAnalysis(ia, fitType = "local")

Arguments

ia

fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and other relevant information.

fitType

Parameter for DESeq2s estimateDispersions(). Should be either "parametric", "local", "mean", or "glmGamPoi" for the type of fitting of dispersions to the mean intensity.

Value

sia object with GRanges of DESeq results in the diff slot.

References

https://doi.org/10.1186/s13059-014-0550-8

Examples

config <- system.file("extdata", "Datasets", "Demo", "info.yaml",
    package = "fourSynergy"
)
res_path <- system.file("extdata", "results", "Demo",
    package = "fourSynergy"
)
tracks <- system.file("extdata", "results", "Demo", "alignment",
    package = "fourSynergy"
)
sia <- createIa(res_path = res_path, config = config, tracks = tracks)
sia <- consensusIa(ia = sia, model = "AUPRC")
sia <- differentialAnalysis(ia = sia, fitType = "mean")

fourSynergy Class

Description

S4 class storing data collected from 4C-seq analyses.

Slots

metadata

Experimental metadata from config file.

expInteractions

Base tool interactions found in the experiment.

ctrlInteractions

Base tool interactions found in the control.

expConsensus

Consensus interactions found in the experiment.

ctrlConsensus

Consensus interactions found in the control.

vp

Viewpoint position.

vfl

Virtual fragment library.

tracks

Path to the alignment files.

differential

Results of differential interaction calling (res).

dds

Results of differential interaction calling (dds).


plotBaseTracks

Description

plotBaseTracks

Usage

plotBaseTracks(ia, highlight_regions = NULL, max_range = 3000)

Arguments

ia

fourSynergy object with interactions from all base tools

highlight_regions

regions to highlight in the plot

max_range

maximum plotting range

Value

Track-plots for all treatments with interactions from base tools

Examples

config <- system.file("extdata", "Datasets", "Demo", "info.yaml",
    package = "fourSynergy"
)
res_path <- system.file("extdata", "results", "Demo",
    package = "fourSynergy"
)
tracks <- system.file("extdata", "results", "Demo", "alignment",
    package = "fourSynergy"
)
sia <- createIa(res_path = res_path, config = config, tracks = tracks)
plotBaseTracks(sia)

plotConsensusIa

Description

This function creates a karyotype plot displaying the interaction calls from the consensus approach.

Usage

plotConsensusIa(
  ia = GRangesList(),
  genes_of_interest = NULL,
  cex.chr = 1,
  cex.ideo = 0.6,
  cex.y.lab = 0.6,
  cex.y.track = 0.6,
  cex.vp = 1,
  cex.leg = 0.6,
  highlight_regions = NULL,
  plot_spider = FALSE,
  gene.name.cex = 1
)

Arguments

ia

fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and other relevant information.

genes_of_interest

Vector with genes of interest. Set to all if you want to plot all genes in this area.

cex.chr

character expansion of chromosome label.

cex.ideo

character expansion base numbers of ideogram.

cex.y.lab

character expansion for y labels.

cex.y.track

character expansion y axis track.

cex.vp

character expansion viewpoint label.

cex.leg

character expansion for legend.

highlight_regions

regions to highlight in the plot.

plot_spider

plotting connections from VP to interactions.

gene.name.cex

character expansion for gene names.

Value

karyoplot with calling results.

Examples

config <- system.file("extdata", "Datasets", "Demo", "info.yaml",
    package = "fourSynergy"
)
res_path <- system.file("extdata", "results", "Demo",
    package = "fourSynergy"
)
tracks <- system.file("extdata", "results", "Demo", "alignment",
    package = "fourSynergy"
)
sia <- createIa(res_path = res_path, config = config, tracks = tracks)
sia <- consensusIa(ia = sia, model = "AUPRC")
plotConsensusIa(ia = sia)

plotConsensusTracks

Description

plotConsensusTracks

Usage

plotConsensusTracks(ia, highlight_regions = NULL, max_range = 3000)

Arguments

ia

fourSynergy object with interactions from all base tools

highlight_regions

regions to highlight in the plot

max_range

maximum plotting range

Value

Track-plots for all treatments with interactions from consensus tool

Examples

config <- system.file("extdata", "Datasets", "Demo", "info.yaml",
    package = "fourSynergy"
)
res_path <- system.file("extdata", "results", "Demo",
    package = "fourSynergy"
)
tracks <- system.file("extdata", "results", "Demo", "alignment",
    package = "fourSynergy"
)
sia <- createIa(res_path = res_path, config = config, tracks = tracks)
sia <- consensusIa(sia, model = "AUPRC")
plotConsensusTracks(sia)

plotDiffIa

Description

This function creates a karyoplot with the differential interactions calls.

Usage

plotDiffIa(
  ia,
  genes_of_interest = NULL,
  cex.chr = 1,
  cex.y.lab = 0.6,
  cex.ideo = 0.6,
  cex.y.track = 0.6,
  cex.vp = 1,
  cex.leg = 0.6,
  plot_spider = FALSE,
  highlight_regions = NULL,
  gene.name.cex = 1
)

Arguments

ia

fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and more relevant information.

genes_of_interest

Vector with genes of interest. Set to all if you want to plot all genes in this area.

cex.chr

character expansion of chromosome label.

cex.y.lab

character expansion for y labels.

cex.ideo

character expansion base numbers of ideogram.

cex.y.track

character expansion y axis track.

cex.vp

character expansion viewpoint label.

cex.leg

character expansion for legend.

plot_spider

plotting connections from VP to interactions

highlight_regions

regions to highlight in the plot

gene.name.cex

character expansion for gene names.

Value

DESeq2 results of differential interaction calling.

Examples

config <- system.file("extdata", "Datasets", "Demo", "info.yaml",
    package = "fourSynergy"
)
res_path <- system.file("extdata", "results", "Demo",
    package = "fourSynergy"
)
tracks <- system.file("extdata", "results", "Demo", "alignment",
    package = "fourSynergy"
)
sia <- createIa(res_path = res_path, config = config, tracks = tracks)
sia <- consensusIa(ia = sia, model = "AUPRC")
sia <- differentialAnalysis(ia = sia, fitType = "mean")
plotDiffIa(ia = sia)

This function creates a karyoplot with the interactions calls of the individual tools.

Description

This function creates a karyoplot with the interactions calls of the individual tools.

Usage

plotIaIndiviualTools(
  ia,
  genes_of_interest = NULL,
  cex.chr = 1,
  cex.ideo = 0.6,
  cex.y.track = 0.6,
  cex.y.lab = 0.6,
  cex.vp = 1,
  cex.leg = 0.6,
  highlight_regions = NULL,
  gene.name.cex = 1
)

Arguments

ia

fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and other relevant information.

genes_of_interest

Vector with genes of interest. Set to all if you want to plot all genes in this area.

cex.chr

character expansion of chromosome label.

cex.ideo

character expansion base numbers of ideogram.

cex.y.track

character expansion y axis track.

cex.y.lab

character expansion y lab.

cex.vp

character expansion viewpoint label.

cex.leg

character expansion for legend.

highlight_regions

regions to highlight in the plot

gene.name.cex

character expansion for gene names.

Value

karyoplot with calling results.

Examples

config <- system.file("extdata", "Datasets", "Demo", "info.yaml",
    package = "fourSynergy"
)
res_path <- system.file("extdata", "results", "Demo",
    package = "fourSynergy"
)
tracks <- system.file("extdata", "results", "Demo", "alignment",
    package = "fourSynergy"
)
sia <- createIa(res_path = res_path, config = config, tracks = tracks)
plotIaIndiviualTools(ia = sia)