| Title: | Ensemble algorithm for 4C-seq data |
|---|---|
| Description: | fourSynergy is an ensemble algorithm leveraging synergies among the existing 4C-seq algorithms r3C-seq, peakC, r.4cker and fourSig. It uses a weighted voting approach to perform improved interaction calling. fourSynergy supports also differential interaction calling. |
| Authors: | Sophie Wind [aut, cre] (ORCID: <https://orcid.org/0009-0002-1174-8201>), Carolin Walter [aut, fnd] (ORCID: <https://orcid.org/0000-0002-5155-7728>) |
| Maintainer: | Sophie Wind <[email protected]> |
| License: | LGPL-3 |
| Version: | 1.1.0 |
| Built: | 2026-04-30 17:39:24 UTC |
| Source: | https://github.com/bioc/fourSynergy |
fourSynergy is an ensemble algorithm leveraging synergies among the existing 4C-seq algorithms r3C-seq, peakC, r.4cker and fourSig. It uses a weighted voting approach to perform improved interaction calling. fourSynergy supports also differential interaction calling.
Maintainer: Sophie Wind [email protected] (ORCID)
Authors:
Carolin Walter [email protected] (ORCID) [funder]
Useful links:
Report bugs at https://github.com/sophiewind/fourSynergy/issues
checkConfig
checkConfig(config)checkConfig(config)
config |
config file with path. |
TRUE if config is valid.
config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy") checkConfig(config)config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy") checkConfig(config)
This function performs an optimized weighted voting of 4C-seq tools.
consensusIa(ia, model = "F1")consensusIa(ia, model = "F1")
ia |
fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and other relevant information. |
model |
Selected optimization model. Either 'F1' or 'AUPRC'. |
fourSynergy object with interactions from all base tools and weighted voting results.
config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(ia = sia, model = "AUPRC")config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(ia = sia, model = "AUPRC")
This function reads the interaction bed files created by the pipeline and transfers this information into an GrangesList.
createIa(res_path = character(), config = list(), tracks = "")createIa(res_path = character(), config = list(), tracks = "")
res_path |
Path to results created by the pipeline.
Typically stored in the |
config |
Path of config file. |
tracks |
Path to alignment files. |
fourSynergy object with interactions from all base tools.
config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) ia <- createIa(res_path = res_path, config = config, tracks = tracks)config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) ia <- createIa(res_path = res_path, config = config, tracks = tracks)
This function performs differential analysis to identify differential interacting regions using DESeq2.
differentialAnalysis(ia, fitType = "local")differentialAnalysis(ia, fitType = "local")
ia |
fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and other relevant information. |
fitType |
Parameter for DESeq2s estimateDispersions(). Should be either "parametric", "local", "mean", or "glmGamPoi" for the type of fitting of dispersions to the mean intensity. |
sia object with GRanges of DESeq results in the diff slot.
https://doi.org/10.1186/s13059-014-0550-8
config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(ia = sia, model = "AUPRC") sia <- differentialAnalysis(ia = sia, fitType = "mean")config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(ia = sia, model = "AUPRC") sia <- differentialAnalysis(ia = sia, fitType = "mean")
S4 class storing data collected from 4C-seq analyses.
metadataExperimental metadata from config file.
expInteractionsBase tool interactions found in the experiment.
ctrlInteractionsBase tool interactions found in the control.
expConsensusConsensus interactions found in the experiment.
ctrlConsensusConsensus interactions found in the control.
vpViewpoint position.
vflVirtual fragment library.
tracksPath to the alignment files.
differentialResults of differential interaction calling (res).
ddsResults of differential interaction calling (dds).
plotBaseTracks
plotBaseTracks(ia, highlight_regions = NULL, max_range = 3000)plotBaseTracks(ia, highlight_regions = NULL, max_range = 3000)
ia |
fourSynergy object with interactions from all base tools |
highlight_regions |
regions to highlight in the plot |
max_range |
maximum plotting range |
Track-plots for all treatments with interactions from base tools
config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) plotBaseTracks(sia)config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) plotBaseTracks(sia)
This function creates a karyotype plot displaying the interaction calls from the consensus approach.
plotConsensusIa( ia = GRangesList(), genes_of_interest = NULL, cex.chr = 1, cex.ideo = 0.6, cex.y.lab = 0.6, cex.y.track = 0.6, cex.vp = 1, cex.leg = 0.6, highlight_regions = NULL, plot_spider = FALSE, gene.name.cex = 1 )plotConsensusIa( ia = GRangesList(), genes_of_interest = NULL, cex.chr = 1, cex.ideo = 0.6, cex.y.lab = 0.6, cex.y.track = 0.6, cex.vp = 1, cex.leg = 0.6, highlight_regions = NULL, plot_spider = FALSE, gene.name.cex = 1 )
ia |
fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and other relevant information. |
genes_of_interest |
Vector with genes of interest. Set to |
cex.chr |
character expansion of chromosome label. |
cex.ideo |
character expansion base numbers of ideogram. |
cex.y.lab |
character expansion for y labels. |
cex.y.track |
character expansion y axis track. |
cex.vp |
character expansion viewpoint label. |
cex.leg |
character expansion for legend. |
highlight_regions |
regions to highlight in the plot. |
plot_spider |
plotting connections from VP to interactions. |
gene.name.cex |
character expansion for gene names. |
karyoplot with calling results.
config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(ia = sia, model = "AUPRC") plotConsensusIa(ia = sia)config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(ia = sia, model = "AUPRC") plotConsensusIa(ia = sia)
plotConsensusTracks
plotConsensusTracks(ia, highlight_regions = NULL, max_range = 3000)plotConsensusTracks(ia, highlight_regions = NULL, max_range = 3000)
ia |
fourSynergy object with interactions from all base tools |
highlight_regions |
regions to highlight in the plot |
max_range |
maximum plotting range |
Track-plots for all treatments with interactions from consensus tool
config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(sia, model = "AUPRC") plotConsensusTracks(sia)config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(sia, model = "AUPRC") plotConsensusTracks(sia)
This function creates a karyoplot with the differential interactions calls.
plotDiffIa( ia, genes_of_interest = NULL, cex.chr = 1, cex.y.lab = 0.6, cex.ideo = 0.6, cex.y.track = 0.6, cex.vp = 1, cex.leg = 0.6, plot_spider = FALSE, highlight_regions = NULL, gene.name.cex = 1 )plotDiffIa( ia, genes_of_interest = NULL, cex.chr = 1, cex.y.lab = 0.6, cex.ideo = 0.6, cex.y.track = 0.6, cex.vp = 1, cex.leg = 0.6, plot_spider = FALSE, highlight_regions = NULL, gene.name.cex = 1 )
ia |
fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and more relevant information. |
genes_of_interest |
Vector with genes of interest. Set to |
cex.chr |
character expansion of chromosome label. |
cex.y.lab |
character expansion for y labels. |
cex.ideo |
character expansion base numbers of ideogram. |
cex.y.track |
character expansion y axis track. |
cex.vp |
character expansion viewpoint label. |
cex.leg |
character expansion for legend. |
plot_spider |
plotting connections from VP to interactions |
highlight_regions |
regions to highlight in the plot |
gene.name.cex |
character expansion for gene names. |
DESeq2 results of differential interaction calling.
config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(ia = sia, model = "AUPRC") sia <- differentialAnalysis(ia = sia, fitType = "mean") plotDiffIa(ia = sia)config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) sia <- consensusIa(ia = sia, model = "AUPRC") sia <- differentialAnalysis(ia = sia, fitType = "mean") plotDiffIa(ia = sia)
This function creates a karyoplot with the interactions calls of the individual tools.
plotIaIndiviualTools( ia, genes_of_interest = NULL, cex.chr = 1, cex.ideo = 0.6, cex.y.track = 0.6, cex.y.lab = 0.6, cex.vp = 1, cex.leg = 0.6, highlight_regions = NULL, gene.name.cex = 1 )plotIaIndiviualTools( ia, genes_of_interest = NULL, cex.chr = 1, cex.ideo = 0.6, cex.y.track = 0.6, cex.y.lab = 0.6, cex.vp = 1, cex.leg = 0.6, highlight_regions = NULL, gene.name.cex = 1 )
ia |
fourSynergy object with interactions from all base tools (peakC, r3c-seq, fourSig, r4cker) and other relevant information. |
genes_of_interest |
Vector with genes of interest. Set to |
cex.chr |
character expansion of chromosome label. |
cex.ideo |
character expansion base numbers of ideogram. |
cex.y.track |
character expansion y axis track. |
cex.y.lab |
character expansion y lab. |
cex.vp |
character expansion viewpoint label. |
cex.leg |
character expansion for legend. |
highlight_regions |
regions to highlight in the plot |
gene.name.cex |
character expansion for gene names. |
karyoplot with calling results.
config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) plotIaIndiviualTools(ia = sia)config <- system.file("extdata", "Datasets", "Demo", "info.yaml", package = "fourSynergy" ) res_path <- system.file("extdata", "results", "Demo", package = "fourSynergy" ) tracks <- system.file("extdata", "results", "Demo", "alignment", package = "fourSynergy" ) sia <- createIa(res_path = res_path, config = config, tracks = tracks) plotIaIndiviualTools(ia = sia)